@@ -1,10 +1,10 @@
-__version__ = "1.0.1"
+import importlib.metadata
 
-
-from .sheet import Sheet
 from .book import Book
-from .nodes import Cell, Box, Col, Row, Table
+from .nodes import Box, Cell, Col, Row, Table
+from .sheet import Sheet
 from .writer import BytesIOWorkBook
 
-
 __all__ = ["Sheet", "Book", "Cell", "Box", "Col", "Row", "Table", "BytesIOWorkBook"]
+
+__version__ = importlib.metadata.version("poi")
