@@ -1,16 +1,15 @@
 from __future__ import annotations
 
 from io import BytesIO
-from typing import List
 
-from . import Sheet
+from .sheet import Sheet
 from .visitors.writer import writer_visitor
-from .writer import Writer, BytesIOWorkBook
+from .writer import BytesIOWorkBook, Writer
 
 
 class Book:
     def __init__(self) -> None:
-        self.sheets: List[Sheet] = []
+        self.sheets: list[Sheet] = []
 
     def add_sheet(self, worksheet: Sheet) -> None:
         self.sheets.append(worksheet)
